==> flavio-0.28.tar.gz: flavio-0.28/README.md <==
<a href="https://travis-ci.org/flav-io/flavio">![Build Status](https://travis-ci.org/flav-io/flavio.svg?branch=master)</a> [![Coverage Status](https://coveralls.io/repos/github/flav-io/flavio/badge.svg)](https://coveralls.io/github/flav-io/flavio) [![DOI](https://zenodo.org/badge/22356/flav-io/flavio.svg)](https://zenodo.org/badge/latestdoi/22356/flav-io/flavio)

# flavio – flavour phenomenology in the Standard model and beyond

flavio is a Python package to compute observables in flavour physics both in
the Standard Model and in the presence of new physics encoded in Wilson
coefficients of dimension-6 operators.

## Project web site

Further information and the package documentation can be found at:

http://flav-io.github.io

This web site is built with Jekyll and hosted on Github pages. You can check
out its source (or submit pull requests) at https://github.com/flav-io/flav-io.github.io.

## Installation

See http://flav-io.github.io/docs/installation.html for instructions.

## Bugs and feature request

Please submit bugs and feature request using
[Github's issue system](https://github.com/flav-io/flavio/issues) rather than
by E-mail. Thanks!

## Contributors

Main author:

- David M. Straub (<david.straub@tum.de>)

Contributors:

- Frederik Beaujean
- Ece Gürler
- Jacky Kumar
- Christoph Niehoff
- Albert Puig
- Stefanie Reichert
- Peter Stangl
- Zeren Simon Wang

## License

flavio is released under the MIT license.

## Citation

If you use flavio in a project, please cite:

[![DOI](https://zenodo.org/badge/22356/flav-io/flavio.svg)](https://zenodo.org/badge/latestdoi/22356/flav-io/flavio)

==> flavio-1.1.tar.gz: flavio-1.1/README.md <==
<a href="https://travis-ci.org/flav-io/flavio">![Build Status](https://travis-ci.org/flav-io/flavio.svg?branch=master)</a> [![Coverage Status](https://coveralls.io/repos/github/flav-io/flavio/badge.svg)](https://coveralls.io/github/flav-io/flavio) [![DOI](https://zenodo.org/badge/22356/flav-io/flavio.svg)](https://zenodo.org/badge/latestdoi/22356/flav-io/flavio)

# flavio – flavour phenomenology in the Standard model and beyond

flavio is a Python package to compute observables in flavour physics both in
the Standard Model and in the presence of new physics encoded in Wilson
coefficients of dimension-6 operators.

## Project web site

Further information and the package documentation can be found at:

http://flav-io.github.io

This web site is built with Jekyll and hosted on Github pages. You can check
out its source (or submit pull requests) at https://github.com/flav-io/flav-io.github.io.

## Installation

See http://flav-io.github.io/docs/installation.html for instructions.

## Bugs and feature request

Please submit bugs and feature request using
[Github's issue system](https://github.com/flav-io/flavio/issues) rather than
by E-mail. Thanks!

## Contributors

Main author:

- David M. Straub (<david.straub@tum.de>)

Contributors (in alphabetical order):

- Jason Aebischer
- Frederik Beaujean
- Ece Gürler
- Matthew Kirk
- Jacky Kumar
- Christoph Niehoff
- Albert Puig
- Stefanie Reichert
- Peter Stangl
- Zeren Simon Wang

## License

flavio is released under the MIT license.

## Citation

If you use flavio in a scientific publication, please cite:

> D. Straub, "flavio: a Python package for flavour and precision
phenomenology in the Standard Model and beyond", [arXiv:1810.08132](https://arxiv.org/abs/1810.08132)

This paper contains many references to results in the literature that went
into the code. Please also consider citing the relevant original literature,
where the real work was done.

The flavio repository itself is also citable via a DOI provided by Zenodo:

[![DOI](https://zenodo.org/badge/22356/flav-io/flavio.svg)](https://zenodo.org/badge/latestdoi/22356/flav-io/flavio)
